!> @addtogroup toolbox 
!! @{
!------------------------------------------------------------------------------
!
! MODULE: system_tools 
!
!! DESCRIPTION:
!> This module implements system access to show resources informations of the application.
!> @author
!> Patrick BEGOU, LEGI
!>
!> @details
!! This module uses iso_c_binging to call C routines that provides system information.
!! This first version only provides the maximum resident state of the current processus
!! (compatibility with previous implemetation by J.B. Lagaert)
!------------------------------------------------------------------------------
module system_tools 

    use iso_c_binding

    implicit none

    public  

    interface
      subroutine get_max_memory_used (maxres) bind (c, name="get_max_memory_used")
        use iso_c_binding
        implicit none
        integer(kind=C_LONG) :: maxres
      end subroutine get_max_memory_used
    end interface

contains

    !------------------------------------------------------------------------------
    !> Show memory used by the simulation - to trak memory leak
    !!    @param[in]    spec_rank   = mpi rank inside the spectral communicator
    !! @author Patrick Begou
    !------------------------------------------------------------------------------
    subroutine show_memory(rank)
      implicit none
      integer, intent(in) :: rank
      integer(kind=C_LONG):: maxres

      call get_max_memory_used (maxres)

      if (rank.EQ.0) write(6,'(2(a,i0),a)') "[INFO MEMORY] : processor ",rank," uses  ",&
         & maxres," kb max of resident memory"

    end subroutine show_memory

end module system_tools 
!> @}
